@@ -34,6 +34,43 @@ sub create_card {
     return $self->post($self->_uri('cards'), $card);
 }
 
+sub get_customer {
+    my ($self, $id) = @_;
+    croak 'The id param is missing' unless defined $id;
+    return $self->get($self->_uri('customers', $id));
+}
+
+sub create_customer {
+    my ($self, $customer) = @_;
+    $customer ||= {};
+    croak 'The customer param must be a hashref' unless ref $customer eq 'HASH';
+    return $self->post($self->_uri('customers'), $customer);
+}
+
+sub get_debit {
+    my ($self, $id) = @_;
+    croak 'The id param is missing' unless defined $id;
+    return $self->get($self->_uri('debits', $id));
+}
+
+sub get_bank_account {
+    my ($self, $id) = @_;
+    croak 'The id param is missing' unless defined $id;
+    return $self->get($self->_uri('bank_accounts', $id));
+}
+
+sub create_bank_account {
+    my ($self, $bank) = @_;
+    croak 'The bank account must be a hashref' unless ref $bank eq 'HASH';
+    return $self->post($self->_uri('bank_accounts'), $bank);
+}
+
+sub get_credit {
+    my ($self, $id) = @_;
+    croak 'The id param is missing' unless defined $id;
+    return $self->get($self->_uri('credits', $id));
+}
+
 sub log {
     my ($self, $msg) = @_;
     return unless $self->logger;
@@ -60,7 +97,7 @@ Business::BalancedPayments::Base
 
 =head1 VERSION
 
-version 1.0000
+version 1.0100
 
 =head1 AUTHORS
 
@@ -68,6 +105,10 @@ version 1.0000
 
 =item *
 
+Ali Anari <ali@tilt.com>
+
+=item *
+
 Khaled Hussein <khaled@tilt.com>
 
 =item *
